@@ -31,12 +31,22 @@ public slots:
 private:
   QTcpServer server;
   QTcpSocket* client;
+  QHttp* searchResults;
+  QUrl url;
+
 
 
 private slots:
     void on_cmbLanguages_editTextChanged(QString );
     void btnCommandTest_clicked();
     void btneSpeakLine_Clicked();
+    void ReadXML(QString xmlfile);
+    void SaveLog();
+    void ParseXML(QXmlStreamReader& obj);
+    void updateXML(bool error);
+    void LoadConfig();
+    void SaveConfig();
+    void LoadVoice();
 };
 
 #endif // MAINWINDOW_H
